export library

Classes

AnimatedBlocBuilder<B extends StateStreamable<S>, S>
A generic widget for animated transitions between bloc states
AnimatedBlocConsumer<B extends StateStreamable<S>, S>
A generic widget for animated transitions between bloc states with event handling

Enums

StateTransitionType
Animation type for state transitions